clojask-io.core


excel-formatclj

source

format-sep-mapclj

source

gen-formatclj

source

infer-formatclj

(infer-format path)

infer the file format from a path, otherwise return nil

infer the file format from a path, otherwise return nil
sourceraw docstring

is-excelclj

(is-excel path)
source

is-generalclj

(is-general path)
source

supportsclj

(supports format)
source

cljdoc builds & hosts documentation for Clojure/Script libraries