clojask-io.delimiter


check-delimiterclj

(check-delimiter x y string-of-a-row)
source

format-delimiterclj

(format-delimiter delimiter)
source

get-all-lenx-stringclj

(get-all-lenx-string vector-of-str max-len)
source

get-delimiterclj

(get-delimiter name)
(get-delimiter name max-len)
source

get-delimiter-mainclj

(get-delimiter-main name)
(get-delimiter-main name max-len)

reads in specified number of lines and stores frequencies of each line in a vector

reads in specified number of lines  and stores frequencies of each line in a vector
sourceraw docstring

get-one-stringclj

(get-one-string vector-of-str str-len start-pos)
source

intersectionclj

(intersection s1 s2)

Return a set that is the intersection of the input sets

Return a set that is the intersection of the input sets
sourceraw docstring

my-frequenciesclj

(my-frequencies string-of-a-row max-len)
source

quote-flagclj

source

read-with-escapeclj

(read-with-escape string-of-a-row)
source

reduce-candidatesclj

(reduce-candidates map-of-candidates string-of-a-row)
source

resultclj

source

result-vecclj

source

slash-flagclj

source

updatedclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries